/*
   Copyright (C) 2000 Marek Michalkiewicz <marekm@linux.org.pl>

   Permission to use, copy, modify, and distribute this software and
   its documentation for any purpose and without fee is hereby granted,
   without any conditions or restrictions.  This software is provided
   "as is" without express or implied warranty.
 */

/*
   ina90.h - this is an attempt to provide some compatibility with
   header files that come with IAR C, to make porting applications
   between different compilers easier.  No 100% compatibility though.
 */

#ifndef _INA90_H_
#define _INA90_H_ 1

#define _CLI() __asm__ __volatile__ ("cli")
#define _SEI() __asm__ __volatile__ ("sei")
#define _NOP() __asm__ __volatile__ ("nop")
#define _WDR() __asm__ __volatile__ ("wdr")
#define _SLEEP() __asm__ __volatile__ ("sleep")
#define _OPC(op) __asm__ __volatile__ (".word %0" : : "n" (op))

#define _LPM_new(addr) ({			\
	unsigned short __addr = (unsigned short)(addr); \
	unsigned char __result;			\
	__asm__ __volatile__ (			\
		"lpm %0, Z" "\n\t"		\
		: "=r" (__result)		\
		: "z" (__addr)			\
	);					\
	__result;				\
 })

#define _LPM_old(addr) ({			\
	unsigned short __addr = (unsigned short)(addr); \
	unsigned char __result;			\
	__asm__ __volatile__ (			\
		"lpm" "\n\t"			\
		"mov %0, r0"			\
		: "=r" (__result)		\
		: "z" (__addr)			\
		: "r0"				\
	);					\
	__result;				\
 })

/*
   This could be more efficient using "movw" if there was a way to
   specify alternatives in "asm" just like they work in *.md:
   if %1 is even (matches the "v" constraint), use "movw r30, %A1"
   else ("r" constraint) use "movw r31, %B1 $ movw r30, %A1"
 */
#define _ELPM_new(addr) ({			\
	unsigned long __addr = (unsigned long)(addr); \
	unsigned char __result;			\
	__asm__ __volatile__ (			\
		"out %2, %C1" "\n\t"		\
		"mov r31, %B1" "\n\t"		\
		"mov r30, %A1" "\n\t"		\
		"elpm %0, Z" "\n\t"		\
		: "=r" (__result)		\
		: "r" (__addr), "I" (RAMPZ)	\
		: "r30", "r31"			\
	);					\
	__result;				\
 })

#define _ELPM_old(addr) ({			\
	unsigned long __addr = (unsigned long)(addr); \
	unsigned char __result;			\
	__asm__ __volatile__ (			\
		"out %2, %C1" "\n\t"		\
		"mov r31, %B1" "\n\t"		\
		"mov r30, %A1" "\n\t"		\
		"elpm" "\n\t"			\
		"mov %0, r0"			\
		: "=r" (__result)		\
		: "r" (__addr), "I" (RAMPZ)	\
		: "r0", "r30", "r31"		\
	);					\
	__result;				\
 })

#if AVR_HAVE_LPMX
/* works only on avr4 (ATmega161) */
#define _LPM(addr) _LPM_new(addr)
#define _ELPM(addr) _ELPM_new(addr)
#else
#define _LPM(addr) _LPM_old(addr)
#define _ELPM(addr) _ELPM_old(addr)
#endif

/* _EEGET, _EEPUT */
#include <eeprom.h>

#define input(port) inp(port)
#define output(port, val) outp(val, port)

#define _inp_blk_op(port, addr, cnt, op) {	\
	unsigned char i = (cnt);		\
	unsigned char *a = (addr);		\
	while (i) {				\
		*(a op) = input(port);		\
		i--;				\
	}					\
 }

#define input_block_inc(port, addr, cnt) _inp_blk_op(port, addr, cnt, ++)
#define input_block_dec(port, addr, cnt) _inp_blk_op(port, addr, cnt, --)

#define _out_blk_op(port, addr, cnt, op) {	\
	unsigned char i = (cnt);		\
	const unsigned char *a = (addr);	\
	while (i) {				\
		output(port, *(a op));		\
		i--;				\
	}					\
 }

#define output_block_inc(port, addr, cnt, op) _out_blk_op(port, addr, cnt, ++)
#define output_block_dec(port, addr, cnt, op) _out_blk_op(port, addr, cnt, --)

#endif

