/*
   Copyright (C) 2000 Marek Michalkiewicz <marekm@linux.org.pl>

   Permission to use, copy, modify, and distribute this software and
   its documentation for any purpose and without fee is hereby granted,
   without any conditions or restrictions.  This software is provided
   "as is" without express or implied warranty.
 */

/*
   pgmspace.h - this is an attempt to provide some compatibility with
   header files that come with IAR C, to make porting applications
   between different compilers easier.  No 100% compatibility though
   (GCC does not have full support for multiple address spaces yet).
 */

#ifndef _PGMSPACE_H_
#define _PGMSPACE_H_

#define __need_size_t
#include <stddef.h>

#include <io.h>

#define PROGMEM __attribute__ ((progmem))

typedef void prog_void PROGMEM;
typedef char prog_char PROGMEM;
typedef int prog_int PROGMEM;
typedef long prog_long PROGMEM;
typedef long long prog_long_long PROGMEM;

#define PSTR(s) ({static char c[] PROGMEM = s; c;})

/* _LPM(), _ELPM() */
#include <ina90.h>

static inline char __lpm_inline(unsigned int addr) __attribute__((const));
static inline char __lpm_inline(unsigned int addr)
{
	return _LPM(addr);
}

#if (FLASHEND > 0x10000)  /* >64K program memory (ATmega103) */

/*
   use this for access to >64K program memory (ATmega103),
   addr = RAMPZ:r31:r30 (if possible, put your constant tables in the
   lower 64K and use "lpm" - it is more efficient that way, and you can
   still use the upper 64K for executable code).
 */

static inline char __elpm_inline(unsigned long addr) __attribute__((const));
static inline char __elpm_inline(unsigned long addr)
{
	return _ELPM(addr);
}

#endif

#define PRG_RDB(addr) __lpm_inline((unsigned short)(addr))

#ifndef PGM_P
#define PGM_P const prog_char *
#endif

#ifndef PGM_VOID_P
#define PGM_VOID_P const prog_void *
#endif

extern void *memcpy_P(void *, PGM_VOID_P, size_t);
extern int strcmp_P(const char *, PGM_P);
extern char *strcpy_P(char *, PGM_P);
extern size_t strlen_P(PGM_P);
extern int strncmp_P(const char *, PGM_P, size_t);
extern char *strncpy_P(char *, PGM_P, size_t);

#if 0  /* not implemented yet */
extern int printf_P(PGM_P, ...);
extern int puts_P(PGM_P);
extern int scanf_P(PGM_P, ...);
extern int sprintf_P(char *, PGM_P, ...);
extern int sscanf_P(const char *, PGM_P, ...);
extern PGM_P strerror_P(int);
#endif

#endif /* _PGMSPACE_H_ */

